@@ -2,12 +2,12 @@
 #'
 #'Deprecated. Use \code{as.mids()} instead.
 #'@aliases long2mids
-#'@param x
+#'@param x argument
 #'@return An object of class \code{mids}
 #'@author Stef van Buuren, 2012
 #'@seealso \code{\link{as.mids}}
 #'@keywords internal
 
 long2mids <- function(x){
-    cat("Deprecated.\n")
+    cat("Deprecated. Use as.mids().\n")
 }
